%Replication files for
%Schoder and Tercioglu (2023): A Climate-Fiscal Policy Mix to Achieve Turkiye's Net-Zero Ambition under Feasibility Constraints. Policy Research Working Paper. World Bank Group.

%0- REQUIREMETS
%    RStudio
%    Mablab plus Dynare Version 5.0 or newer 
%    Code needs to be run sequentially


%1- PREPARE THE DATASET
%The raw data is in 'data/Turkey_data.xls'. The sheet is exported to 'data/Turkey_data.csv'. 
%Run data/Turkey_data.Rmd in RStudio (approx. run time: 1m)
copyfile('data/data.csv','estimation/data.csv')
copyfile('data/data.csv','smoothed_variables/data.csv')
copyfile('data/data.csv','conditional_forecast/data.csv')
copyfile('data/data.csv','credible_interval/data.csv')
copyfile('data/raw_data.csv','figures/raw_data.csv')


%2- ESTIMATE THE MODEL
%Approx. run time: 6h
%Useful resources: https://www.dynare.org/manual/
run('estimation/main_estimation.m')
copyfile('estimation/estimation/metropolis','smoothed_variables/estimation/metropolis')
copyfile('estimation/estimation/Output/estimation_mode.mat','smoothed_variables/estimation_mode.mat')


%3- SENSITIVITY ANALYSIS
%Approx. run time: 30m
run('sensitivity/main_sensitivity.m')


%4- GENERATE SMOOTHED VARIABLES USING ESTIMATED POSTERIOR DISTRIUBTIONS
%Approx. run time: 2m
run('smoothed_variables/main_smoothed.m')
copyfile('smoothed_variables/estimation/Output/estimation_results.mat','impulse_responses/model/estimation_results.mat')
copyfile('smoothed_variables/estimation/Output/estimation_results.mat','conditional_forecast/estimation_results.mat')
copyfile('smoothed_variables/estimation/Output/estimation_results.mat','welfare_analysis/estimation_results.mat')
copyfile('smoothed_variables/estimation/Output/estimation_results.mat','expectations/estimation_results.mat')
copyfile('smoothed_variables/estimation/Output/estimation_results.mat','credible_interval/estimation_results.mat')
copyfile('smoothed_variables/estimation/Output/estimation_results.mat','figures/estimation_results.mat')
copyfile('smoothed_variables/estimation/metropolis','credible_interval/estimation/metropolis')
copyfile('smoothed_variables/+estimation','expectations/+estimation')


%5- IMPULSE RESPONSES
%Approx. run time: 4m
run('impulse_responses/main_impulse.m')
copyfile('impulse_responses/model/simulation/Output/simulation_results_tO.mat','figures/simulation_results_tO.mat')
copyfile('impulse_responses/model/simulation/Output/simulation_results_sER.mat','figures/simulation_results_sER.mat')
copyfile('impulse_responses/model/simulation/Output/simulation_results_IGRgen.mat','figures/simulation_results_IGRgen.mat')
copyfile('impulse_responses/model/simulation/Output/simulation_results_IGRinffree.mat','figures/simulation_results_IGRinffree.mat')
copyfile('impulse_responses/model/simulation/Output/simulation_results_IGRinf.mat','figures/simulation_results_IGRinf.mat')


%6- CONDITIONAL FORECASTS
%Approx. run time: 30m
run('conditional_forecast/main_conditionalforecast.m')
copyfile('conditional_forecast/cond_forecast_policy.mat','welfare_analysis/cond_forecast_policy.mat')
copyfile('conditional_forecast/cond_forecast_policy.mat','expectations/cond_forecast_policy.mat')
copyfile('conditional_forecast/cond_forecast_policy.mat','figures/cond_forecast_policy.mat')
copyfile('conditional_forecast/cond_forecast_nopolicy.mat','welfare_analysis/cond_forecast_nopolicy.mat')
copyfile('conditional_forecast/cond_forecast_nopolicy.mat','figures/cond_forecast_nopolicy.mat')
copyfile('conditional_forecast/cond_forecast_fiscon.mat','figures/cond_forecast_fiscon.mat')
copyfile('conditional_forecast/cond_forecast_policy_delay_noBG_nosERd.mat','figures/cond_forecast_policy_delay_noBG_nosERd.mat')
copyfile('conditional_forecast/cond_forecast_policy_GamS.mat','figures/cond_forecast_policy_GamS.mat')
copyfile('conditional_forecast/cond_forecast_policy_lamER.mat','figures/cond_forecast_policy_lamER.mat')
copyfile('conditional_forecast/kink_index.mat','credible_interval/kink_index.mat')


%7- WELFARE ANALYSIS
%Approx. run time: 45m
%Many thanks to Johannes Pfeiffer for sharing relevant code. 
run('welfare_analysis/main_welfare.m')
copyfile('welfare_analysis/lambda_unconditional_H.mat','figures/lambda_unconditional_H.mat')
copyfile('welfare_analysis/lambda_unconditional_H_wealth.mat','figures/lambda_unconditional_H_wealth.mat')
copyfile('welfare_analysis/lambda_unconditional_L.mat','figures/lambda_unconditional_L.mat')


%8- DIFFERENT ASSUMPTIONS REGARDING EXPECTATION FORMATION
%Approx. run time: 45m
run('expectations/main_expectations.m')
copyfile('expectations/simul_surprise.mat','figures/simul_surprise.mat')
copyfile('expectations/simul_reversal.mat','figures/simul_reversal.mat')
copyfile('expectations/simul_perfect_foresight.mat','figures/simul_perfect_foresight.mat')


%9- CREDIBLE INTERVAL
%Approx. run time: 72h
run('credible_interval/main_credible.m')
copyfile('credible_interval/ci_up.mat','figures/ci_up.mat')
copyfile('credible_interval/ci_low.mat','figures/ci_low.mat')
copyfile('credible_interval/ci_up_nopolicy.mat','figures/ci_up_nopolicy.mat')
copyfile('credible_interval/ci_low_nopolicy.mat','figures/ci_low_nopolicy.mat')
copyfile('credible_interval/ci_up_dev.mat','figures/ci_up_dev.mat')
copyfile('credible_interval/ci_low_dev.mat','figures/ci_low_dev.mat')
copyfile('credible_interval/estimation/metropolis','time_varying_elasticity/estimation/metropolis')


%10- TIME VARYING ELASTICITY
%Approx. run time: 20s
run('time_varying_elasticity/main_elasticity.m')
copyfile('time_varying_elasticity/time_varying_elasticity.mat','figures/time_varying_elasticity.mat')


%11- FIGURES
%Approx. run time: 1m
run('figures/figures.m')


%12- COLLECT ALL RESULTS IN THE FOLDER "OUTPUT"
%Approx. run time: 1s
%The estimation results reported in Tables B4 and B5 can be found in "smoothed_variables/estimation.log"
copyfile('figures/Figure_2.eps','output/Figure_2.eps')
copyfile('figures/Figure_3a.eps','output/Figure_3a.eps')
copyfile('figures/Figure_3b.eps','output/Figure_3b.eps')
copyfile('figures/Figure_3c.eps','output/Figure_3c.eps')
copyfile('figures/Figure_3d.eps','output/Figure_3d.eps')
copyfile('figures/Figure_4a.eps','output/Figure_4a.eps')
copyfile('figures/Figure_4b.eps','output/Figure_4b.eps')
copyfile('figures/Figure_4c.eps','output/Figure_4c.eps')
copyfile('figures/Figure_4d.eps','output/Figure_4d.eps')
copyfile('figures/Figure_5a.eps','output/Figure_5a.eps')
copyfile('figures/Figure_5b.eps','output/Figure_5b.eps')
copyfile('figures/Figure_6a.eps','output/Figure_6a.eps')
copyfile('figures/Figure_6b.eps','output/Figure_6b.eps')
copyfile('figures/Figure_6c.eps','output/Figure_6c.eps')
copyfile('figures/Figure_6d.eps','output/Figure_6d.eps')
copyfile('figures/Figure_6e.eps','output/Figure_6e.eps')
copyfile('figures/Figure_6f.eps','output/Figure_6f.eps')
copyfile('figures/Figure_7a.eps','output/Figure_7a.eps')
copyfile('figures/Figure_7b.eps','output/Figure_7b.eps')
copyfile('figures/Figure_7c.eps','output/Figure_7c.eps')
copyfile('figures/Figure_7d.eps','output/Figure_7d.eps')
copyfile('figures/Figure_B1.eps','output/Figure_B1.eps')
copyfile('sensitivity/estimation/gsa/estimation_prior_stable.eps','output/Figure_B2a.eps')
copyfile('sensitivity/estimation/gsa/estimation_prior_indeterm.eps','output/Figure_B2b.eps')


